@@ -1,6 +1,6 @@
 /*
  * Carla common defines
- * Copyright (C) 2011-2022 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2011-2024 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,11 +18,6 @@
 #ifndef CARLA_DEFINES_H_INCLUDED
 #define CARLA_DEFINES_H_INCLUDED
 
-/* IDE Helper */
-#ifndef REAL_BUILD
-# include "config.h"
-#endif
-
 /* Compatibility with non-clang compilers */
 #ifndef __has_feature
 # define __has_feature(x) 0
@@ -32,8 +27,8 @@
 #endif
 
 /* Set Version */
-#define CARLA_VERSION_HEX    0x020502
-#define CARLA_VERSION_STRING "2.5.2"
+#define CARLA_VERSION_HEX    0x020508
+#define CARLA_VERSION_STRING "2.5.8"
 #define CARLA_VERSION_STRMIN "2.5"
 
 /* Check OS */
